use strict;
use vars qw(%PREREQ %RECOMMEND %BUILD_REQ);
use Module::Build;

do 'PREREQ' or die "Error including PREREQ: $@";

Module::Build->new(
   module_name    => 'Sys::Info',
   license        => 'perl',
   requires       => \%PREREQ,
   build_requires => \%BUILD_REQ,
   recommends     => \%RECOMMEND,
   sign           => 0,
   dist_author    => 'Burak Gursoy <burak@cpan.org>',
)->create_build_script;
